Class: Pod::Command::Jsource
- Inherits:
-
Pod::Command
- Object
- Pod::Command
- Pod::Command::Jsource
- Defined in:
- lib/cocoapods-jsource/command/jsource.rb,
lib/cocoapods-jsource/command/jsource/add.rb,
lib/cocoapods-jsource/command/jsource/list.rb,
lib/cocoapods-jsource/command/jsource/clean.rb,
lib/cocoapods-jsource/command/xcode_manager.rb
Overview
Create a PR to add your plugin to CocoaPods/cocoapods.org in the plugins.json file, once your plugin is released.
This is an example of a cocoapods plugin adding a top-level subcommand to the ‘pod’ command.
You can also create subcommands of existing or new commands. Say you wanted to add a subcommand to list to show newly deprecated pods, (e.g. ‘pod list deprecated`), there are a few things that would need to change.
-
move this file to
lib/pod/command/list/deprecated.rband update the class to exist in the the Pod::Command::List namespace -
change this class to extend from
Listinstead ofCommand. This tells the plugin system that it is a subcommand oflist. -
edit
lib/cocoapods_plugins.rbto require this file
Direct Known Subclasses
Add, Clean, List, XcodeManager
Defined Under Namespace
Classes: Add, Clean, List, XcodeManager